@@ -1,25 +1,25 @@
 var searchData=
 [
   ['i_20change_20what_20is_20after_20the_20include_20in_20the_20class_20documentation_0',['How can I change what is after the \#include in the class documentation?',['../faq.html#faq_code_inc',1,'']]],
-  ['i_20configure_20doxygen_20from_20the_20command_20line_1',['Can I configure doxygen from the command line?',['../faq.html#faq_cmdline',1,'']]],
+  ['i_20configure_20doxygen_20from_20the_20command_20line_1',['Can I configure Doxygen from the command line?',['../faq.html#faq_cmdline',1,'']]],
   ['i_20do_2',['I don&apos;t like the quick index that is put above each HTML page, what do I do?',['../faq.html#faq_html',1,'']]],
   ['i_20don_20t_20like_20the_20quick_20index_20that_20is_20put_20above_20each_20html_20page_20what_20do_20i_20do_3',['I don&apos;t like the quick index that is put above each HTML page, what do I do?',['../faq.html#faq_html',1,'']]],
   ['i_20exclude_20all_20test_20directories_20from_20my_20directory_20tree_4',['How can I exclude all test directories from my directory tree?',['../faq.html#faq_excl_dir',1,'']]],
   ['i_20get_20tex_20capacity_20exceeded_20now_20what_5',['When running make in the latex directory I get &quot;TeX capacity exceeded&quot;. Now what?',['../faq.html#faq_latex',1,'']]],
   ['i_20get_20the_20cryptic_20message_20input_20buffer_20overflow_20can_20t_20enlarge_20buffer_20because_20scanner_20uses_20reject_6',['Help! I get the cryptic message &quot;input buffer overflow, can&apos;t enlarge buffer because scanner uses REJECT&quot;',['../faq.html#faq_lex',1,'']]],
   ['i_20have_20problems_20getting_20the_20search_20engine_20to_20work_20with_20php5_20and_20or_20windows_7',['I have problems getting the search engine to work with PHP5 and/or windows',['../faq.html#faq_search',1,'']]],
-  ['i_20make_20doxygen_20ignore_20some_20code_20fragment_8',['How can I make doxygen ignore some code fragment?',['../faq.html#faq_code',1,'']]],
+  ['i_20make_20doxygen_20ignore_20some_20code_20fragment_8',['How can I make Doxygen ignore some code fragment?',['../faq.html#faq_code',1,'']]],
   ['i_20only_20wanted_20to_20use_20my_20own_20html_20header_20file_9',['The overall HTML output looks different, while I only wanted to use my own html header file',['../faq.html#faq_html_header',1,'']]],
   ['i_20prevent_20that_20at_20a_20certain_20place_10',['Doxygen automatically generates a link to the class MyClass somewhere in the running text.  How do I prevent that at a certain place?',['../faq.html#faq_class',1,'']]],
   ['i_20set_20extract_5fall_20to_20no_20none_20of_20my_20functions_20are_20shown_20in_20the_20documentation_11',['When I set EXTRACT_ALL to NO none of my functions are shown in the documentation.',['../faq.html#faq_extract_all',1,'']]],
-  ['i_20still_20use_20doxygen_12',['My favorite programming language is X. Can I still use doxygen?',['../faq.html#faq_pgm_X',1,'']]],
+  ['i_20still_20use_20doxygen_12',['My favorite programming language is X. Can I still use Doxygen?',['../faq.html#faq_pgm_X',1,'']]],
   ['i_20use_20tag_20files_20in_20combination_20with_20compressed_20html_13',['How can I use tag files in combination with compressed HTML?',['../faq.html#faq_chm',1,'']]],
   ['id_20attributes_14',['Header Id Attributes',['../markdown.html#md_header_id',1,'']]],
   ['idlexcept_20name_15',['\\idlexcept \&lt;name\&gt;',['../commands.html#cmdidlexcept',1,'']]],
-  ['if_20doxygen_20supports_20your_20programming_20hardware_20description_20language_16',['Step 0: Check if doxygen supports your programming/hardware description language',['../starting.html#step0',1,'']]],
+  ['if_20doxygen_20supports_20your_20programming_20hardware_20description_20language_16',['Step 0: Check if Doxygen supports your programming/hardware description language',['../starting.html#step0',1,'']]],
   ['if_20section_20label_17',['\\if (section-label)',['../commands.html#cmdif',1,'']]],
   ['ifnot_20section_20label_18',['\\ifnot (section-label)',['../commands.html#cmdifnot',1,'']]],
-  ['ignore_20some_20code_20fragment_19',['How can I make doxygen ignore some code fragment?',['../faq.html#faq_code',1,'']]],
+  ['ignore_20some_20code_20fragment_19',['How can I make Doxygen ignore some code fragment?',['../faq.html#faq_code',1,'']]],
   ['ignored_20',['\\noop ( text to be ignored )',['../commands.html#cmdnoop',1,'']]],
   ['image_20attributes_21',['Image Attributes',['../markdown.html#md_image_attributes',1,'']]],
   ['image_20option_20option_20format_20file_20caption_20sizeindication_20size_22',['\\image[&apos;{&apos;option[,option]&apos;}&apos;] \&lt;format\&gt; \&lt;file\&gt; [&quot;caption&quot;] [\&lt;sizeindication\&gt;=\&lt;size\&gt;]',['../commands.html#cmdimage',1,'']]],
@@ -76,7 +76,7 @@ var searchData=
   ['is_20not_20parsed_20properly_20anymore_73',['My file with a custom extension is not parsed (properly) (anymore).',['../faq.html#faq_ext_mapping',1,'']]],
   ['is_20put_20above_20each_20html_20page_20what_20do_20i_20do_74',['I don&apos;t like the quick index that is put above each HTML page, what do I do?',['../faq.html#faq_html',1,'']]],
   ['is_20to_20be_20done_75',['\\todo { paragraph describing what is to be done }',['../commands.html#cmdtodo',1,'']]],
-  ['is_20x_20can_20i_20still_20use_20doxygen_76',['My favorite programming language is X. Can I still use doxygen?',['../faq.html#faq_pgm_X',1,'']]],
+  ['is_20x_20can_20i_20still_20use_20doxygen_76',['My favorite programming language is X. Can I still use Doxygen?',['../faq.html#faq_pgm_X',1,'']]],
   ['item_20description_77',['item description',['../commands.html#cmdarg',1,'\\arg { item-description }'],['../commands.html#cmdli',1,'\\li { item-description }']]],
-  ['its_20name_78',['How did doxygen get its name?',['../faq.html#faq_name',1,'']]]
+  ['its_20name_78',['How did Doxygen get its name?',['../faq.html#faq_name',1,'']]]
 ];
