@@ -27,7 +27,7 @@ var searchData=
   ['the_20class_20documentation_24',['How can I change what is after the \#include in the class documentation?',['../faq.html#faq_code_inc',1,'']]],
   ['the_20class_20myclass_20somewhere_20in_20the_20running_20text_20how_20do_20i_20prevent_20that_20at_20a_20certain_20place_25',['Doxygen automatically generates a link to the class MyClass somewhere in the running text.  How do I prevent that at a certain place?',['../faq.html#faq_class',1,'']]],
   ['the_20code_26',['Documenting the code',['../docblocks.html',1,'']]],
-  ['the_20command_20line_27',['Can I configure doxygen from the command line?',['../faq.html#faq_cmdline',1,'']]],
+  ['the_20command_20line_27',['Can I configure Doxygen from the command line?',['../faq.html#faq_cmdline',1,'']]],
   ['the_20cryptic_20message_20input_20buffer_20overflow_20can_20t_20enlarge_20buffer_20because_20scanner_20uses_20reject_28',['Help! I get the cryptic message &quot;input buffer overflow, can&apos;t enlarge buffer because scanner uses REJECT&quot;',['../faq.html#faq_lex',1,'']]],
   ['the_20docbook_20output_29',['Configuration options related to the DOCBOOK output',['../config.html#config_docbook',1,'']]],
   ['the_20documentation_30',['When I set EXTRACT_ALL to NO none of my functions are shown in the documentation.',['../faq.html#faq_extract_all',1,'']]],
@@ -51,7 +51,7 @@ var searchData=
   ['the_20precondition_48',['\\pre { description of the precondition }',['../commands.html#cmdpre',1,'']]],
   ['the_20preprocessor_49',['Configuration options related to the preprocessor',['../config.html#config_preprocessor',1,'']]],
   ['the_20quick_20index_20that_20is_20put_20above_20each_20html_20page_20what_20do_20i_20do_50',['I don&apos;t like the quick index that is put above each HTML page, what do I do?',['../faq.html#faq_html',1,'']]],
-  ['the_20reason_20to_20develop_20doxygen_51',['What was the reason to develop doxygen?',['../faq.html#faq_why',1,'']]],
+  ['the_20reason_20to_20develop_20doxygen_51',['What was the reason to develop Doxygen?',['../faq.html#faq_why',1,'']]],
   ['the_20result_20value_52',['\\result { description of the result value }',['../commands.html#cmdresult',1,'']]],
   ['the_20return_20value_53',['the return value',['../commands.html#cmdreturn',1,'\\return { description of the return value }'],['../commands.html#cmdreturns',1,'\\returns { description of the return value }']]],
   ['the_20rtf_20output_54',['Configuration options related to the RTF output',['../config.html#config_rtf',1,'']]],
@@ -69,7 +69,7 @@ var searchData=
   ['to_20be_20ignored_66',['\\noop ( text to be ignored )',['../commands.html#cmdnoop',1,'']]],
   ['to_20be_20shown_20as_20warning_67',['\\raisewarning ( text to be shown as warning )',['../commands.html#cmdraisewarning',1,'']]],
   ['to_20classes_68',['Links to classes',['../autolink.html#linkclass',1,'']]],
-  ['to_20develop_20doxygen_69',['What was the reason to develop doxygen?',['../faq.html#faq_why',1,'']]],
+  ['to_20develop_20doxygen_69',['What was the reason to develop Doxygen?',['../faq.html#faq_why',1,'']]],
   ['to_20diagram_20generator_20tools_70',['Configuration options related to diagram generator tools',['../config.html#config_dot',1,'']]],
   ['to_20external_20documentation_71',['Linking to external documentation',['../external.html',1,'']]],
   ['to_20external_20references_72',['Configuration options related to external references',['../config.html#config_external',1,'']]],
